# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blobstorage_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import blobstorage_disk_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__disk__pb2
from ydb.core.protos import blobstorage_disk_color_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__disk__color__pb2
from ydb.core.protos import blobstorage_pdisk_config_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__pdisk__config__pb2
from ydb.core.protos import blob_depot_config_pb2 as ydb_dot_core_dot_protos_dot_blob__depot__config__pb2
from library.cpp.actors.protos import interconnect_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_interconnect__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ydb/core/protos/blobstorage_config.proto\x12\x12NKikimrBlobStorage\x1a&ydb/core/protos/blobstorage_disk.proto\x1a,ydb/core/protos/blobstorage_disk_color.proto\x1a.ydb/core/protos/blobstorage_pdisk_config.proto\x1a\'ydb/core/protos/blob_depot_config.proto\x1a,library/cpp/actors/protos/interconnect.proto\"\xbe\x01\n\x10THostConfigDrive\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12,\n\x04Type\x18\x02 \x01(\x0e\x32\x1e.NKikimrBlobStorage.EPDiskType\x12\x14\n\x0cSharedWithOs\x18\x03 \x01(\x08\x12\x13\n\x0bReadCentric\x18\x04 \x01(\x08\x12\x0c\n\x04Kind\x18\x05 \x01(\x04\x12\x35\n\x0bPDiskConfig\x18\x06 \x01(\x0b\x32 .NKikimrBlobStorage.TPDiskConfig\"\xcc\x01\n\x11TDefineHostConfig\x12\x14\n\x0cHostConfigId\x18\x01 \x01(\x04\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x33\n\x05\x44rive\x18\x03 \x03(\x0b\x32$.NKikimrBlobStorage.THostConfigDrive\x12@\n\x16\x44\x65\x66\x61ultHostPDiskConfig\x18\x04 \x01(\x0b\x32 .NKikimrBlobStorage.TPDiskConfig\x12\x1c\n\x14ItemConfigGeneration\x18\x64 \x01(\x04\"\'\n\x0fTReadHostConfig\x12\x14\n\x0cHostConfigId\x18\x01 \x03(\x04\"G\n\x11TDeleteHostConfig\x12\x14\n\x0cHostConfigId\x18\x01 \x01(\x04\x12\x1c\n\x14ItemConfigGeneration\x18\x64 \x01(\x04\"8\n\x08THostKey\x12\x0c\n\x04\x46qdn\x18\x01 \x01(\t\x12\x0e\n\x06IcPort\x18\x02 \x01(\x05\x12\x0e\n\x06NodeId\x18\x03 \x01(\r\"`\n\x05THost\x12)\n\x03Key\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.THostKey\x12\x14\n\x0cHostConfigId\x18\x02 \x01(\x04\x12\x16\n\x0e\x45nforcedNodeId\x18\x03 \x01(\r\"\x80\x01\n\nTDefineBox\x12\r\n\x05\x42oxId\x18\x01 \x01(\x04\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x0e\n\x06UserId\x18\x03 \x03(\x0c\x12\'\n\x04Host\x18\x04 \x03(\x0b\x32\x19.NKikimrBlobStorage.THost\x12\x1c\n\x14ItemConfigGeneration\x18\x64 \x01(\x04\"\x19\n\x08TReadBox\x12\r\n\x05\x42oxId\x18\x01 \x03(\x04\"9\n\nTDeleteBox\x12\r\n\x05\x42oxId\x18\x01 \x01(\x04\x12\x1c\n\x14ItemConfigGeneration\x18\x64 \x01(\x04\"\xcd\x01\n\x0eTGroupGeometry\x12\x17\n\x0fRealmLevelBegin\x18\x01 \x01(\r\x12\x15\n\rRealmLevelEnd\x18\x02 \x01(\r\x12\x18\n\x10\x44omainLevelBegin\x18\x03 \x01(\r\x12\x16\n\x0e\x44omainLevelEnd\x18\x04 \x01(\r\x12\x15\n\rNumFailRealms\x18\x05 \x01(\r\x12\"\n\x1aNumFailDomainsPerFailRealm\x18\x06 \x01(\r\x12\x1e\n\x16NumVDisksPerFailDomain\x18\x07 \x01(\r\"\x9f\x01\n\x12TGroupUsagePattern\x12\x12\n\nSpaceBytes\x18\x01 \x01(\x04\x12\x11\n\tWriteIOPS\x18\x02 \x01(\x04\x12\x1b\n\x13WriteBytesPerSecond\x18\x03 \x01(\x04\x12\x10\n\x08ReadIOPS\x18\x04 \x01(\x04\x12\x1a\n\x12ReadBytesPerSecond\x18\x05 \x01(\x04\x12\x17\n\x0fInMemCacheBytes\x18\x06 \x01(\x04\"\xe5\x01\n\x0cTPDiskFilter\x12\x44\n\x08Property\x18\x01 \x03(\x0b\x32\x32.NKikimrBlobStorage.TPDiskFilter.TRequiredProperty\x1a\x8e\x01\n\x11TRequiredProperty\x12.\n\x04Type\x18\x01 \x01(\x0e\x32\x1e.NKikimrBlobStorage.EPDiskTypeH\x00\x12\x16\n\x0cSharedWithOs\x18\x02 \x01(\x08H\x00\x12\x15\n\x0bReadCentric\x18\x03 \x01(\x08H\x00\x12\x0e\n\x04Kind\x18\x04 \x01(\x04H\x00\x42\n\n\x08Property\"\xe7\x04\n\x12TDefineStoragePool\x12\r\n\x05\x42oxId\x18\x01 \x01(\x04\x12\x15\n\rStoragePoolId\x18\x02 \x01(\x04\x12\x0c\n\x04Name\x18\x03 \x01(\t\x12\x16\n\x0e\x45rasureSpecies\x18\x04 \x01(\t\x12\x34\n\x08Geometry\x18\x05 \x01(\x0b\x32\".NKikimrBlobStorage.TGroupGeometry\x12\x11\n\tVDiskKind\x18\x06 \x01(\t\x12<\n\x0cUsagePattern\x18\x07 \x01(\x0b\x32&.NKikimrBlobStorage.TGroupUsagePattern\x12\x0c\n\x04Kind\x18\x08 \x01(\t\x12\x11\n\tNumGroups\x18\t \x01(\r\x12\x0e\n\x06UserId\x18\n \x03(\x0c\x12\x35\n\x0bPDiskFilter\x18\x0b \x03(\x0b\x32 .NKikimrBlobStorage.TPDiskFilter\x12N\n\x0e\x45xistingGroups\x18\x0c \x01(\x0b\x32\x36.NKikimrBlobStorage.TDefineStoragePool.TExistingGroups\x12.\n\x07ScopeId\x18\r \x01(\x0b\x32\x1d.NActorsInterconnect.TScopeId\x12\x1d\n\x15RandomizeGroupMapping\x18\x0e \x01(\x08\x12\x1d\n\x15\x45xpectedGroupSlotSize\x18\x0f \x03(\x04\x12\x1c\n\x14ItemConfigGeneration\x18\x64 \x01(\x04\x12\x16\n\x0e\x45ncryptionMode\x18\x65 \x01(\r\x1a\"\n\x0fTExistingGroups\x12\x0f\n\x07GroupId\x18\x01 \x03(\r\"F\n\x10TReadStoragePool\x12\r\n\x05\x42oxId\x18\x01 \x01(\x04\x12\x15\n\rStoragePoolId\x18\x02 \x03(\x04\x12\x0c\n\x04Name\x18\x03 \x03(\t\"X\n\x12TDeleteStoragePool\x12\r\n\x05\x42oxId\x18\x01 \x01(\x04\x12\x15\n\rStoragePoolId\x18\x02 \x01(\x04\x12\x1c\n\x14ItemConfigGeneration\x18\x64 \x01(\x04\"X\n\x0cTGroupStatus\"H\n\x01\x45\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x12\x0b\n\x07PARTIAL\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\x12\x11\n\rDISINTEGRATED\x10\x04\"X\n\x0fTDriveLifeStage\"E\n\x01\x45\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08NOT_SEEN\x10\x01\x12\r\n\tALLOCATED\x10\x02\x12\x0b\n\x07REMOVED\x10\x03\x12\t\n\x05\x45RROR\x10\x04\"U\n\x16TSerialManagementStage\";\n\x01\x45\x12\x13\n\x0f\x44ISCOVER_SERIAL\x10\x00\x12\x10\n\x0c\x43HECK_SERIAL\x10\x01\x12\x0f\n\x0bONLY_SERIAL\x10\x02\"\x80\x02\n\x12TUpdateDriveStatus\x12-\n\x07HostKey\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.THostKey\x12\x0c\n\x04Path\x18\x02 \x01(\t\x12\x30\n\x06Status\x18\x03 \x01(\x0e\x32 .NKikimrBlobStorage.EDriveStatus\x12\x0f\n\x07PDiskId\x18\x04 \x01(\r\x12\x0e\n\x06Serial\x18\x05 \x01(\t\x12\x1d\n\x15StatusChangeTimestamp\x18\x06 \x01(\x04\x12;\n\x0e\x44\x65\x63ommitStatus\x18\x07 \x01(\x0e\x32#.NKikimrBlobStorage.EDecommitStatus\"O\n\x10TReadDriveStatus\x12-\n\x07HostKey\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.THostKey\x12\x0c\n\x04Path\x18\x02 \x01(\t\"\x16\n\x14TProposeStoragePools\"\x12\n\x10TQueryBaseConfig\"\x0f\n\rTReadSettings\"+\n\x08TPDiskId\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0f\n\x07PDiskId\x18\x02 \x01(\r\"\xcd\x01\n\x12TReassignGroupDisk\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\x12\x17\n\x0fGroupGeneration\x18\x02 \x01(\r\x12\x14\n\x0c\x46\x61ilRealmIdx\x18\x03 \x01(\r\x12\x15\n\rFailDomainIdx\x18\x04 \x01(\r\x12\x10\n\x08VDiskIdx\x18\x05 \x01(\r\x12\x33\n\rTargetPDiskId\x18\x06 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TPDiskId\x12\x19\n\x11SuppressDonorMode\x18\x07 \x01(\x08\"!\n\x0eTSanitizeGroup\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\"^\n\x0bTClusterFit\x12;\n\tAlgorithm\x18\x01 \x01(\x0e\x32(.NKikimrBlobStorage.EClusterFitAlgorithm\x12\x12\n\nIterations\x18\x02 \x01(\x04\"M\n\x0cTVSlotMetric\x12-\n\x07VSlotId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12\x0e\n\x06Metric\x18\x02 \x01(\x04\"\xe9\x01\n\x11TClusterFitConfig\x12\x33\n\nBaseConfig\x18\x01 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TBaseConfig\x12;\n\x0bStoragePool\x18\x02 \x03(\x0b\x32&.NKikimrBlobStorage.TDefineStoragePool\x12\x30\n\x06Metric\x18\x03 \x03(\x0b\x32 .NKikimrBlobStorage.TVSlotMetric\x12\x30\n\x07Request\x18\x04 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TClusterFit\"\x8d\x02\n\x0bTMergeBoxes\x12\x13\n\x0bOriginBoxId\x18\x01 \x01(\x04\x12\x1b\n\x13OriginBoxGeneration\x18\x02 \x01(\x04\x12\x13\n\x0bTargetBoxId\x18\x03 \x01(\x04\x12\x1b\n\x13TargetBoxGeneration\x18\x04 \x01(\x04\x12K\n\x10StoragePoolIdMap\x18\x05 \x03(\x0b\x32\x31.NKikimrBlobStorage.TMergeBoxes.TStoragePoolIdMap\x1aM\n\x11TStoragePoolIdMap\x12\x1b\n\x13OriginStoragePoolId\x18\x01 \x01(\x04\x12\x1b\n\x13TargetStoragePoolId\x18\x02 \x01(\x04\"\xb9\x01\n\x0bTMoveGroups\x12\r\n\x05\x42oxId\x18\x01 \x01(\x04\x12\x1b\n\x13OriginStoragePoolId\x18\x02 \x01(\x04\x12#\n\x1bOriginStoragePoolGeneration\x18\x03 \x01(\x04\x12\x1b\n\x13TargetStoragePoolId\x18\x04 \x01(\x04\x12#\n\x1bTargetStoragePoolGeneration\x18\x05 \x01(\x04\x12\x17\n\x0f\x45xplicitGroupId\x18\x06 \x03(\r\"X\n\x11TAddMigrationPlan\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x35\n\x0bMoveCommand\x18\x02 \x03(\x0b\x32 .NKikimrBlobStorage.TMoveCommand\"$\n\x14TDeleteMigrationPlan\x12\x0c\n\x04Name\x18\x01 \x01(\t\"!\n\x0fTEnableSelfHeal\x12\x0e\n\x06\x45nable\x18\x01 \x01(\x08\"\"\n\x10TEnableDonorMode\x12\x0e\n\x06\x45nable\x18\x01 \x01(\x08\"\xae\x06\n\x0eTDeclareIntent\x12;\n\x07Intents\x18\x01 \x03(\x0b\x32*.NKikimrBlobStorage.TDeclareIntent.TIntent\x12\x15\n\rDropUniqueIds\x18\x02 \x03(\t\x1a]\n\x0eTAffectedGroup\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\x12:\n\x06Impact\x18\x02 \x01(\x0e\x32*.NKikimrBlobStorage.TDeclareIntent.EImpact\x1ai\n\x0bTDenyReason\x12\x0f\n\x07Message\x18\x01 \x01(\t\x12I\n\x0e\x41\x66\x66\x65\x63tedGroups\x18\x02 \x03(\x0b\x32\x31.NKikimrBlobStorage.TDeclareIntent.TAffectedGroup\x1a\xe8\x02\n\x07TIntent\x12\x10\n\x08UniqueId\x18\x01 \x01(\t\x12\x36\n\x04Kind\x18\x02 \x01(\x0e\x32(.NKikimrBlobStorage.TDeclareIntent.EKind\x12\x16\n\x0e\x42\x65ginTimestamp\x18\x03 \x01(\x04\x12\x14\n\x0c\x45ndTimestamp\x18\x04 \x01(\x04\x12?\n\x06\x41\x63tion\x18\x05 \x01(\x0e\x32/.NKikimrBlobStorage.TDeclareIntent.EDriveAction\x12-\n\x07HostKey\x18\x06 \x01(\x0b\x32\x1c.NKikimrBlobStorage.THostKey\x12\x0c\n\x04Path\x18\x07 \x01(\t\x12\x0f\n\x07PDiskId\x18\x08 \x01(\r\x12\x12\n\nDriveSerNo\x18\t \x01(\t\x12\x42\n\nDenyReason\x18\x64 \x01(\x0b\x32..NKikimrBlobStorage.TDeclareIntent.TDenyReason\"#\n\x05\x45Kind\x12\x0b\n\x07REQUEST\x10\x00\x12\r\n\tSTATEMENT\x10\x01\"(\n\x0c\x45\x44riveAction\x12\x0b\n\x07REPLACE\x10\x00\x12\x0b\n\x07OFFLINE\x10\x01\"D\n\x07\x45Impact\x12\x11\n\rGROUP_OFFLINE\x10\x00\x12\x13\n\x0fGROUP_DATA_LOSS\x10\x01\x12\x11\n\rGROUP_FRAGILE\x10\x02\"\r\n\x0bTReadIntent\"n\n\x0eTDropDonorDisk\x12-\n\x07VSlotId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12-\n\x07VDiskId\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\"j\n\nTWipeVDisk\x12-\n\x07VSlotId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12-\n\x07VDiskId\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\"0\n\x14TSetScrubPeriodicity\x12\x18\n\x10ScrubPeriodicity\x18\x01 \x01(\r\"\xa8\x01\n\x0fTAddDriveSerial\x12\x0e\n\x06Serial\x18\x01 \x01(\t\x12\r\n\x05\x42oxId\x18\x02 \x01(\x04\x12\x0c\n\x04Kind\x18\x03 \x01(\x04\x12\x31\n\tPDiskType\x18\x04 \x01(\x0e\x32\x1e.NKikimrBlobStorage.EPDiskType\x12\x35\n\x0bPDiskConfig\x18\x05 \x01(\x0b\x32 .NKikimrBlobStorage.TPDiskConfig\"$\n\x12TRemoveDriveSerial\x12\x0e\n\x06Serial\x18\x01 \x01(\t\"$\n\x12TForgetDriveSerial\x12\x0e\n\x06Serial\x18\x01 \x01(\t\"O\n\x10TMigrateToSerial\x12;\n\x05Stage\x18\x01 \x01(\x0e\x32,.NKikimrBlobStorage.TSerialManagementStage.E\"@\n\x1cTSetPDiskSpaceMarginPromille\x12 \n\x18PDiskSpaceMarginPromille\x18\x01 \x01(\r\"\xdf\x02\n\x0fTUpdateSettings\x12\x17\n\x0f\x44\x65\x66\x61ultMaxSlots\x18\x01 \x03(\r\x12\x16\n\x0e\x45nableSelfHeal\x18\x02 \x03(\x08\x12\x17\n\x0f\x45nableDonorMode\x18\x03 \x03(\x08\x12\x1f\n\x17ScrubPeriodicitySeconds\x18\x04 \x03(\x04\x12 \n\x18PDiskSpaceMarginPromille\x18\x05 \x03(\r\x12\x17\n\x0fGroupReserveMin\x18\x06 \x03(\r\x12\x1b\n\x13GroupReservePartPPM\x18\x07 \x03(\r\x12\x1e\n\x16MaxScrubbedDisksAtOnce\x18\x08 \x03(\r\x12\x45\n\x15PDiskSpaceColorBorder\x18\t \x03(\x0e\x32&.NKikimrBlobStorage.TPDiskSpaceColor.E\x12\"\n\x1a\x45nableGroupLayoutSanitizer\x18\n \x03(\x08\"9\n\x11TBoxStoragePoolId\x12\r\n\x05\x42oxId\x18\x01 \x01(\x04\x12\x15\n\rStoragePoolId\x18\x02 \x01(\x04\"\xf0\x01\n\x15TAllocateVirtualGroup\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0e\n\x06HiveId\x18\x02 \x01(\x04\x12\x19\n\x0fStoragePoolName\x18\x03 \x01(\tH\x00\x12>\n\rStoragePoolId\x18\x04 \x01(\x0b\x32%.NKikimrBlobStorage.TBoxStoragePoolIdH\x00\x12:\n\x0f\x43hannelProfiles\x18\x05 \x03(\x0b\x32!.NKikimrBlobDepot.TChannelProfile\x12\x13\n\x0b\x42lobDepotId\x18\x06 \x01(\x04\x42\r\n\x0bStoragePool\"o\n\x0fTDecommitGroups\x12\x10\n\x08GroupIds\x18\x01 \x03(\r\x12\x0e\n\x06HiveId\x18\x02 \x01(\x04\x12:\n\x0f\x43hannelProfiles\x18\x03 \x03(\x0b\x32!.NKikimrBlobDepot.TChannelProfile\"\xe1\x14\n\x0eTConfigRequest\x12<\n\x07\x43ommand\x18\x01 \x03(\x0b\x32+.NKikimrBlobStorage.TConfigRequest.TCommand\x12\x10\n\x08Rollback\x18\x02 \x01(\x08\x12\x1f\n\x17IgnoreGroupSanityChecks\x18\x03 \x01(\x08\x12\"\n\x1aIgnoreGroupFailModelChecks\x18\x04 \x01(\x08\x12\x1d\n\x15IgnoreVSlotQuotaCheck\x18\x05 \x01(\x08\x12\x1a\n\x12\x41llowUnusableDisks\x18\x06 \x01(\x08\x12\x1a\n\x12IgnoreGroupReserve\x18\x07 \x01(\x08\x12\"\n\x1aIgnoreDegradedGroupsChecks\x18\x08 \x01(\x08\x12\'\n\x1fIgnoreDisintegratedGroupsChecks\x18\x0b \x01(\x08\x12$\n\x1cSettleOnlyOnOperationalDisks\x18\t \x01(\x08\x12\x0c\n\x04\x43ito\x18\n \x01(\x08\x1a\xe1\x11\n\x08TCommand\x12\x41\n\x10\x44\x65\x66ineHostConfig\x18\x01 \x01(\x0b\x32%.NKikimrBlobStorage.TDefineHostConfigH\x00\x12=\n\x0eReadHostConfig\x18\x02 \x01(\x0b\x32#.NKikimrBlobStorage.TReadHostConfigH\x00\x12\x41\n\x10\x44\x65leteHostConfig\x18\x04 \x01(\x0b\x32%.NKikimrBlobStorage.TDeleteHostConfigH\x00\x12\x33\n\tDefineBox\x18\x05 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TDefineBoxH\x00\x12/\n\x07ReadBox\x18\x06 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TReadBoxH\x00\x12\x33\n\tDeleteBox\x18\x08 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TDeleteBoxH\x00\x12\x43\n\x11\x44\x65\x66ineStoragePool\x18\t \x01(\x0b\x32&.NKikimrBlobStorage.TDefineStoragePoolH\x00\x12?\n\x0fReadStoragePool\x18\n \x01(\x0b\x32$.NKikimrBlobStorage.TReadStoragePoolH\x00\x12\x43\n\x11\x44\x65leteStoragePool\x18\x0c \x01(\x0b\x32&.NKikimrBlobStorage.TDeleteStoragePoolH\x00\x12\x43\n\x11UpdateDriveStatus\x18\r \x01(\x0b\x32&.NKikimrBlobStorage.TUpdateDriveStatusH\x00\x12?\n\x0fReadDriveStatus\x18\x0e \x01(\x0b\x32$.NKikimrBlobStorage.TReadDriveStatusH\x00\x12G\n\x13ProposeStoragePools\x18\x0f \x01(\x0b\x32(.NKikimrBlobStorage.TProposeStoragePoolsH\x00\x12?\n\x0fQueryBaseConfig\x18\x10 \x01(\x0b\x32$.NKikimrBlobStorage.TQueryBaseConfigH\x00\x12\x35\n\nMergeBoxes\x18\x17 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TMergeBoxesH\x00\x12\x35\n\nMoveGroups\x18\x18 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TMoveGroupsH\x00\x12\x41\n\x10\x41\x64\x64MigrationPlan\x18\x19 \x01(\x0b\x32%.NKikimrBlobStorage.TAddMigrationPlanH\x00\x12G\n\x13\x44\x65leteMigrationPlan\x18\x1a \x01(\x0b\x32(.NKikimrBlobStorage.TDeleteMigrationPlanH\x00\x12=\n\x0e\x45nableSelfHeal\x18\x1b \x01(\x0b\x32#.NKikimrBlobStorage.TEnableSelfHealH\x00\x12;\n\rDeclareIntent\x18\x1c \x01(\x0b\x32\".NKikimrBlobStorage.TDeclareIntentH\x00\x12\x35\n\nReadIntent\x18\x1d \x01(\x0b\x32\x1f.NKikimrBlobStorage.TReadIntentH\x00\x12>\n\x0f\x45nableDonorMode\x18\x1e \x01(\x0b\x32#.NKikimrBlobStorage.TEnableSelfHealH\x00\x12;\n\rDropDonorDisk\x18\x1f \x01(\x0b\x32\".NKikimrBlobStorage.TDropDonorDiskH\x00\x12G\n\x13SetScrubPeriodicity\x18  \x01(\x0b\x32(.NKikimrBlobStorage.TSetScrubPeriodicityH\x00\x12=\n\x0e\x41\x64\x64\x44riveSerial\x18! \x01(\x0b\x32#.NKikimrBlobStorage.TAddDriveSerialH\x00\x12\x43\n\x11RemoveDriveSerial\x18\" \x01(\x0b\x32&.NKikimrBlobStorage.TRemoveDriveSerialH\x00\x12\x43\n\x11\x46orgetDriveSerial\x18$ \x01(\x0b\x32&.NKikimrBlobStorage.TForgetDriveSerialH\x00\x12?\n\x0fMigrateToSerial\x18# \x01(\x0b\x32$.NKikimrBlobStorage.TMigrateToSerialH\x00\x12W\n\x1bSetPDiskSpaceMarginPromille\x18% \x01(\x0b\x32\x30.NKikimrBlobStorage.TSetPDiskSpaceMarginPromilleH\x00\x12=\n\x0eUpdateSettings\x18& \x01(\x0b\x32#.NKikimrBlobStorage.TUpdateSettingsH\x00\x12I\n\x14\x41llocateVirtualGroup\x18\' \x01(\x0b\x32).NKikimrBlobStorage.TAllocateVirtualGroupH\x00\x12=\n\x0e\x44\x65\x63ommitGroups\x18( \x01(\x0b\x32#.NKikimrBlobStorage.TDecommitGroupsH\x00\x12\x33\n\tWipeVDisk\x18) \x01(\x0b\x32\x1e.NKikimrBlobStorage.TWipeVDiskH\x00\x12;\n\rSanitizeGroup\x18* \x01(\x0b\x32\".NKikimrBlobStorage.TSanitizeGroupH\x00\x12\x39\n\x0cReadSettings\x18+ \x01(\x0b\x32!.NKikimrBlobStorage.TReadSettingsH\x00\x12\x43\n\x11ReassignGroupDisk\x18\x13 \x01(\x0b\x32&.NKikimrBlobStorage.TReassignGroupDiskH\x00\x42\t\n\x07\x43ommand\"\xdf\x0e\n\x0bTBaseConfig\x12\x35\n\x05PDisk\x18\x01 \x03(\x0b\x32&.NKikimrBlobStorage.TBaseConfig.TPDisk\x12\x35\n\x05VSlot\x18\x02 \x03(\x0b\x32&.NKikimrBlobStorage.TBaseConfig.TVSlot\x12\x35\n\x05Group\x18\x03 \x03(\x0b\x32&.NKikimrBlobStorage.TBaseConfig.TGroup\x12\x33\n\x04Node\x18\x04 \x03(\x0b\x32%.NKikimrBlobStorage.TBaseConfig.TNode\x1a\xbc\x04\n\x06TPDisk\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0f\n\x07PDiskId\x18\x02 \x01(\r\x12\x0c\n\x04Path\x18\x03 \x01(\t\x12,\n\x04Type\x18\x04 \x01(\x0e\x32\x1e.NKikimrBlobStorage.EPDiskType\x12\x37\n\x0cSharedWithOs\x18\x05 \x01(\x0e\x32!.NKikimrBlobStorage.ETriStateBool\x12\x36\n\x0bReadCentric\x18\x06 \x01(\x0e\x32!.NKikimrBlobStorage.ETriStateBool\x12\x0c\n\x04Kind\x18\x07 \x01(\x04\x12\x35\n\x0bPDiskConfig\x18\x08 \x01(\x0b\x32 .NKikimrBlobStorage.TPDiskConfig\x12\x0c\n\x04Guid\x18\t \x01(\x04\x12\r\n\x05\x42oxId\x18\n \x01(\x04\x12\x16\n\x0eNumStaticSlots\x18\x0b \x01(\r\x12\x35\n\x0b\x44riveStatus\x18\x0c \x01(\x0e\x32 .NKikimrBlobStorage.EDriveStatus\x12\x19\n\x11\x45xpectedSlotCount\x18\r \x01(\r\x12\x37\n\x0cPDiskMetrics\x18\x0e \x01(\x0b\x32!.NKikimrBlobStorage.TPDiskMetrics\x12\"\n\x1a\x44riveStatusChangeTimestamp\x18\x0f \x01(\x04\x12;\n\x0e\x44\x65\x63ommitStatus\x18\x10 \x01(\x0e\x32#.NKikimrBlobStorage.EDecommitStatus\x1a\x8b\x04\n\x06TVSlot\x12-\n\x07VSlotId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12\x0f\n\x07GroupId\x18\x02 \x01(\r\x12\x17\n\x0fGroupGeneration\x18\x03 \x01(\r\x12\x11\n\tVDiskKind\x18\x04 \x01(\t\x12\x14\n\x0c\x46\x61ilRealmIdx\x18\x05 \x01(\r\x12\x15\n\rFailDomainIdx\x18\x06 \x01(\r\x12\x10\n\x08VDiskIdx\x18\x07 \x01(\r\x12\x15\n\rAllocatedSize\x18\x08 \x01(\x04\x12\x37\n\x0cVDiskMetrics\x18\t \x01(\x0b\x32!.NKikimrBlobStorage.TVDiskMetrics\x12\x0e\n\x06Status\x18\n \x01(\t\x12\x41\n\x06\x44onors\x18\x0b \x03(\x0b\x32\x31.NKikimrBlobStorage.TBaseConfig.TVSlot.TDonorDisk\x12\r\n\x05Ready\x18\x0c \x01(\x08\x1a\xa3\x01\n\nTDonorDisk\x12-\n\x07VDiskId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12-\n\x07VSlotId\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12\x37\n\x0cVDiskMetrics\x18\x03 \x01(\x0b\x32!.NKikimrBlobStorage.TVDiskMetrics\x1a\xb1\x02\n\x06TGroup\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\x12\x17\n\x0fGroupGeneration\x18\x02 \x01(\r\x12\x16\n\x0e\x45rasureSpecies\x18\x03 \x01(\t\x12-\n\x07VSlotId\x18\x04 \x03(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12\r\n\x05\x42oxId\x18\x05 \x01(\x04\x12\x15\n\rStoragePoolId\x18\x06 \x01(\x04\x12\x17\n\x0fSeenOperational\x18\x07 \x01(\x08\x12;\n\x0fOperatingStatus\x18\x08 \x01(\x0e\x32\".NKikimrBlobStorage.TGroupStatus.E\x12:\n\x0e\x45xpectedStatus\x18\t \x01(\x0e\x32\".NKikimrBlobStorage.TGroupStatus.E\x1a\xf4\x01\n\x05TNode\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x1c\n\x10PhysicalLocation\x18\x02 \x01(\x0c\x42\x02\x18\x01\x12-\n\x07HostKey\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.THostKey\x12\x34\n\x08Location\x18\x04 \x01(\x0b\x32\".NActorsInterconnect.TNodeLocation\x12\x1c\n\x14LastConnectTimestamp\x18\x05 \x01(\x04\x12\x1f\n\x17LastDisconnectTimestamp\x18\x06 \x01(\x04\x12\x19\n\x11LastSeenTimestamp\x18\x07 \x01(\x04\"\x90\x01\n\x0cTMoveCommand\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\x12\x14\n\x0cOriginNodeId\x18\x02 \x01(\r\x12\x15\n\rOriginPDiskId\x18\x03 \x01(\r\x12\x15\n\rOriginVSlotId\x18\x04 \x01(\r\x12\x14\n\x0cTargetNodeId\x18\x05 \x01(\r\x12\x15\n\rTargetPDiskId\x18\x06 \x01(\r\"y\n\nTPDiskStat\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0f\n\x07PDiskId\x18\x02 \x01(\r\x12\x0c\n\x04\x46qdn\x18\x03 \x01(\t\x12\x0e\n\x06IcPort\x18\x04 \x01(\x05\x12\x0c\n\x04Path\x18\x05 \x01(\t\x12\x1e\n\x16NumSlotsAfterMigration\x18\x06 \x01(\r\"\xda\x01\n\x0fTReassignedItem\x12-\n\x07VDiskId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12*\n\x04\x46rom\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12(\n\x02To\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12\x10\n\x08\x46romFqdn\x18\x04 \x01(\t\x12\x10\n\x08\x46romPath\x18\x05 \x01(\t\x12\x0e\n\x06ToFqdn\x18\x06 \x01(\t\x12\x0e\n\x06ToPath\x18\x07 \x01(\t\"\xec\x0c\n\x0fTConfigResponse\x12;\n\x06Status\x18\x01 \x03(\x0b\x32+.NKikimrBlobStorage.TConfigResponse.TStatus\x12\x0f\n\x07Success\x18\x02 \x01(\x08\x12\x18\n\x10\x45rrorDescription\x18\x03 \x01(\t\x1a\xf0\x0b\n\x07TStatus\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x18\n\x10\x45rrorDescription\x18\x02 \x01(\t\x12K\n\nFailReason\x18\x0c \x01(\x0e\x32\x37.NKikimrBlobStorage.TConfigResponse.TStatus.EFailReason\x12I\n\tFailParam\x18\r \x03(\x0b\x32\x36.NKikimrBlobStorage.TConfigResponse.TStatus.TFailParam\x12\x39\n\nHostConfig\x18\x03 \x03(\x0b\x32%.NKikimrBlobStorage.TDefineHostConfig\x12+\n\x03\x42ox\x18\x04 \x03(\x0b\x32\x1e.NKikimrBlobStorage.TDefineBox\x12;\n\x0b\x44riveStatus\x18\x05 \x03(\x0b\x32&.NKikimrBlobStorage.TUpdateDriveStatus\x12;\n\x0bStoragePool\x18\x06 \x03(\x0b\x32&.NKikimrBlobStorage.TDefineStoragePool\x12\x33\n\nBaseConfig\x18\x07 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TBaseConfig\x12\x0f\n\x07GroupId\x18\x08 \x03(\r\x12\x1d\n\x15\x41ssignedStoragePoolId\x18\t \x01(\x04\x12\x35\n\x0bMoveCommand\x18\n \x03(\x0b\x32 .NKikimrBlobStorage.TMoveCommand\x12\x31\n\tPDiskStat\x18\x0b \x03(\x0b\x32\x1e.NKikimrBlobStorage.TPDiskStat\x12;\n\x0eReassignedItem\x18\x0e \x03(\x0b\x32#.NKikimrBlobStorage.TReassignedItem\x12\x31\n\tWipeVDisk\x18\x11 \x03(\x0b\x32\x1e.NKikimrBlobStorage.TWipeVDisk\x12\x32\n\x06Intent\x18\x0f \x01(\x0b\x32\".NKikimrBlobStorage.TDeclareIntent\x12\x0f\n\x07\x41lready\x18\x10 \x01(\x08\x12\x35\n\x08Settings\x18\x12 \x01(\x0b\x32#.NKikimrBlobStorage.TUpdateSettings\x1a\x8e\x03\n\nTFailParam\x12\x0e\n\x04\x46qdn\x18\x01 \x01(\tH\x00\x12\x10\n\x06IcPort\x18\x02 \x01(\x05H\x00\x12\x10\n\x06NodeId\x18\x03 \x01(\rH\x00\x12\x11\n\x07PDiskId\x18\x04 \x01(\rH\x00\x12\x0e\n\x04Path\x18\x05 \x01(\tH\x00\x12\x16\n\x0cHostConfigId\x18\x06 \x01(\x04H\x00\x12\x0f\n\x05\x42oxId\x18\x07 \x01(\x04H\x00\x12\x17\n\rStoragePoolId\x18\x08 \x01(\x04H\x00\x12&\n\x1cItemConfigGenerationProvided\x18\t \x01(\x04H\x00\x12&\n\x1cItemConfigGenerationExpected\x18\n \x01(\x04H\x00\x12\x11\n\x07GroupId\x18\x0b \x01(\rH\x00\x12/\n\x07VDiskId\x18\x0c \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskIDH\x00\x12/\n\x07VSlotId\x18\r \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotIdH\x00\x12\x19\n\x0fStoragePoolName\x18\x0e \x01(\tH\x00\x42\x07\n\x05Value\"\xf3\x01\n\x0b\x45\x46\x61ilReason\x12\x0c\n\x08kGeneric\x10\x00\x12\x11\n\rkHostNotFound\x10\x01\x12\x12\n\x0ekPDiskNotFound\x10\x02\x12\x17\n\x13kHostConfigNotFound\x10\x03\x12!\n\x1dkItemConfigGenerationMismatch\x10\x04\x12\x10\n\x0ckMayLoseData\x10\x05\x12\x15\n\x11kVDiskIdIncorrect\x10\x06\x12\x12\n\x0ekVSlotNotFound\x10\x07\x12\x13\n\x0fkDiskIsNotDonor\x10\x08\x12\x0c\n\x08kAlready\x10\t\x12\x13\n\x0fkMayGetDegraded\x10\n*:\n\nEPDiskType\x12\x07\n\x03ROT\x10\x00\x12\x07\n\x03SSD\x10\x01\x12\x08\n\x04NVME\x10\x02\x12\x10\n\x0cUNKNOWN_TYPE\x10\x03*=\n\x12\x45VirtualGroupState\x12\x07\n\x03NEW\x10\x00\x12\x11\n\rCREATE_FAILED\x10\x01\x12\x0b\n\x07WORKING\x10\x02*f\n\x0c\x45\x44riveStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08INACTIVE\x10\x02\x12\n\n\x06\x42ROKEN\x10\x03\x12\n\n\x06\x46\x41ULTY\x10\x05\x12\x11\n\rTO_BE_REMOVED\x10\x06\"\x04\x08\x04\x10\x04*e\n\x0f\x45\x44\x65\x63ommitStatus\x12\x12\n\x0e\x44\x45\x43OMMIT_UNSET\x10\x00\x12\x11\n\rDECOMMIT_NONE\x10\x01\x12\x14\n\x10\x44\x45\x43OMMIT_PENDING\x10\x02\x12\x15\n\x11\x44\x45\x43OMMIT_IMMINENT\x10\x03*C\n\x14\x45\x43lusterFitAlgorithm\x12\r\n\tQUADRATIC\x10\x00\x12\r\n\tHUNGARIAN\x10\x01\x12\r\n\tANNEALING\x10\x02*3\n\rETriStateBool\x12\n\n\x06kFalse\x10\x00\x12\t\n\x05kTrue\x10\x01\x12\x0b\n\x07kNotSet\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blobstorage_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TBASECONFIG_TNODE.fields_by_name['PhysicalLocation']._options = None
  _TBASECONFIG_TNODE.fields_by_name['PhysicalLocation']._serialized_options = b'\030\001'
  _EPDISKTYPE._serialized_start=13533
  _EPDISKTYPE._serialized_end=13591
  _EVIRTUALGROUPSTATE._serialized_start=13593
  _EVIRTUALGROUPSTATE._serialized_end=13654
  _EDRIVESTATUS._serialized_start=13656
  _EDRIVESTATUS._serialized_end=13758
  _EDECOMMITSTATUS._serialized_start=13760
  _EDECOMMITSTATUS._serialized_end=13861
  _ECLUSTERFITALGORITHM._serialized_start=13863
  _ECLUSTERFITALGORITHM._serialized_end=13930
  _ETRISTATEBOOL._serialized_start=13932
  _ETRISTATEBOOL._serialized_end=13983
  _THOSTCONFIGDRIVE._serialized_start=286
  _THOSTCONFIGDRIVE._serialized_end=476
  _TDEFINEHOSTCONFIG._serialized_start=479
  _TDEFINEHOSTCONFIG._serialized_end=683
  _TREADHOSTCONFIG._serialized_start=685
  _TREADHOSTCONFIG._serialized_end=724
  _TDELETEHOSTCONFIG._serialized_start=726
  _TDELETEHOSTCONFIG._serialized_end=797
  _THOSTKEY._serialized_start=799
  _THOSTKEY._serialized_end=855
  _THOST._serialized_start=857
  _THOST._serialized_end=953
  _TDEFINEBOX._serialized_start=956
  _TDEFINEBOX._serialized_end=1084
  _TREADBOX._serialized_start=1086
  _TREADBOX._serialized_end=1111
  _TDELETEBOX._serialized_start=1113
  _TDELETEBOX._serialized_end=1170
  _TGROUPGEOMETRY._serialized_start=1173
  _TGROUPGEOMETRY._serialized_end=1378
  _TGROUPUSAGEPATTERN._serialized_start=1381
  _TGROUPUSAGEPATTERN._serialized_end=1540
  _TPDISKFILTER._serialized_start=1543
  _TPDISKFILTER._serialized_end=1772
  _TPDISKFILTER_TREQUIREDPROPERTY._serialized_start=1630
  _TPDISKFILTER_TREQUIREDPROPERTY._serialized_end=1772
  _TDEFINESTORAGEPOOL._serialized_start=1775
  _TDEFINESTORAGEPOOL._serialized_end=2390
  _TDEFINESTORAGEPOOL_TEXISTINGGROUPS._serialized_start=2356
  _TDEFINESTORAGEPOOL_TEXISTINGGROUPS._serialized_end=2390
  _TREADSTORAGEPOOL._serialized_start=2392
  _TREADSTORAGEPOOL._serialized_end=2462
  _TDELETESTORAGEPOOL._serialized_start=2464
  _TDELETESTORAGEPOOL._serialized_end=2552
  _TGROUPSTATUS._serialized_start=2554
  _TGROUPSTATUS._serialized_end=2642
  _TGROUPSTATUS_E._serialized_start=2570
  _TGROUPSTATUS_E._serialized_end=2642
  _TDRIVELIFESTAGE._serialized_start=2644
  _TDRIVELIFESTAGE._serialized_end=2732
  _TDRIVELIFESTAGE_E._serialized_start=2663
  _TDRIVELIFESTAGE_E._serialized_end=2732
  _TSERIALMANAGEMENTSTAGE._serialized_start=2734
  _TSERIALMANAGEMENTSTAGE._serialized_end=2819
  _TSERIALMANAGEMENTSTAGE_E._serialized_start=2760
  _TSERIALMANAGEMENTSTAGE_E._serialized_end=2819
  _TUPDATEDRIVESTATUS._serialized_start=2822
  _TUPDATEDRIVESTATUS._serialized_end=3078
  _TREADDRIVESTATUS._serialized_start=3080
  _TREADDRIVESTATUS._serialized_end=3159
  _TPROPOSESTORAGEPOOLS._serialized_start=3161
  _TPROPOSESTORAGEPOOLS._serialized_end=3183
  _TQUERYBASECONFIG._serialized_start=3185
  _TQUERYBASECONFIG._serialized_end=3203
  _TREADSETTINGS._serialized_start=3205
  _TREADSETTINGS._serialized_end=3220
  _TPDISKID._serialized_start=3222
  _TPDISKID._serialized_end=3265
  _TREASSIGNGROUPDISK._serialized_start=3268
  _TREASSIGNGROUPDISK._serialized_end=3473
  _TSANITIZEGROUP._serialized_start=3475
  _TSANITIZEGROUP._serialized_end=3508
  _TCLUSTERFIT._serialized_start=3510
  _TCLUSTERFIT._serialized_end=3604
  _TVSLOTMETRIC._serialized_start=3606
  _TVSLOTMETRIC._serialized_end=3683
  _TCLUSTERFITCONFIG._serialized_start=3686
  _TCLUSTERFITCONFIG._serialized_end=3919
  _TMERGEBOXES._serialized_start=3922
  _TMERGEBOXES._serialized_end=4191
  _TMERGEBOXES_TSTORAGEPOOLIDMAP._serialized_start=4114
  _TMERGEBOXES_TSTORAGEPOOLIDMAP._serialized_end=4191
  _TMOVEGROUPS._serialized_start=4194
  _TMOVEGROUPS._serialized_end=4379
  _TADDMIGRATIONPLAN._serialized_start=4381
  _TADDMIGRATIONPLAN._serialized_end=4469
  _TDELETEMIGRATIONPLAN._serialized_start=4471
  _TDELETEMIGRATIONPLAN._serialized_end=4507
  _TENABLESELFHEAL._serialized_start=4509
  _TENABLESELFHEAL._serialized_end=4542
  _TENABLEDONORMODE._serialized_start=4544
  _TENABLEDONORMODE._serialized_end=4578
  _TDECLAREINTENT._serialized_start=4581
  _TDECLAREINTENT._serialized_end=5395
  _TDECLAREINTENT_TAFFECTEDGROUP._serialized_start=4683
  _TDECLAREINTENT_TAFFECTEDGROUP._serialized_end=4776
  _TDECLAREINTENT_TDENYREASON._serialized_start=4778
  _TDECLAREINTENT_TDENYREASON._serialized_end=4883
  _TDECLAREINTENT_TINTENT._serialized_start=4886
  _TDECLAREINTENT_TINTENT._serialized_end=5246
  _TDECLAREINTENT_EKIND._serialized_start=5248
  _TDECLAREINTENT_EKIND._serialized_end=5283
  _TDECLAREINTENT_EDRIVEACTION._serialized_start=5285
  _TDECLAREINTENT_EDRIVEACTION._serialized_end=5325
  _TDECLAREINTENT_EIMPACT._serialized_start=5327
  _TDECLAREINTENT_EIMPACT._serialized_end=5395
  _TREADINTENT._serialized_start=5397
  _TREADINTENT._serialized_end=5410
  _TDROPDONORDISK._serialized_start=5412
  _TDROPDONORDISK._serialized_end=5522
  _TWIPEVDISK._serialized_start=5524
  _TWIPEVDISK._serialized_end=5630
  _TSETSCRUBPERIODICITY._serialized_start=5632
  _TSETSCRUBPERIODICITY._serialized_end=5680
  _TADDDRIVESERIAL._serialized_start=5683
  _TADDDRIVESERIAL._serialized_end=5851
  _TREMOVEDRIVESERIAL._serialized_start=5853
  _TREMOVEDRIVESERIAL._serialized_end=5889
  _TFORGETDRIVESERIAL._serialized_start=5891
  _TFORGETDRIVESERIAL._serialized_end=5927
  _TMIGRATETOSERIAL._serialized_start=5929
  _TMIGRATETOSERIAL._serialized_end=6008
  _TSETPDISKSPACEMARGINPROMILLE._serialized_start=6010
  _TSETPDISKSPACEMARGINPROMILLE._serialized_end=6074
  _TUPDATESETTINGS._serialized_start=6077
  _TUPDATESETTINGS._serialized_end=6428
  _TBOXSTORAGEPOOLID._serialized_start=6430
  _TBOXSTORAGEPOOLID._serialized_end=6487
  _TALLOCATEVIRTUALGROUP._serialized_start=6490
  _TALLOCATEVIRTUALGROUP._serialized_end=6730
  _TDECOMMITGROUPS._serialized_start=6732
  _TDECOMMITGROUPS._serialized_end=6843
  _TCONFIGREQUEST._serialized_start=6846
  _TCONFIGREQUEST._serialized_end=9503
  _TCONFIGREQUEST_TCOMMAND._serialized_start=7230
  _TCONFIGREQUEST_TCOMMAND._serialized_end=9503
  _TBASECONFIG._serialized_start=9506
  _TBASECONFIG._serialized_end=11393
  _TBASECONFIG_TPDISK._serialized_start=9740
  _TBASECONFIG_TPDISK._serialized_end=10312
  _TBASECONFIG_TVSLOT._serialized_start=10315
  _TBASECONFIG_TVSLOT._serialized_end=10838
  _TBASECONFIG_TVSLOT_TDONORDISK._serialized_start=10675
  _TBASECONFIG_TVSLOT_TDONORDISK._serialized_end=10838
  _TBASECONFIG_TGROUP._serialized_start=10841
  _TBASECONFIG_TGROUP._serialized_end=11146
  _TBASECONFIG_TNODE._serialized_start=11149
  _TBASECONFIG_TNODE._serialized_end=11393
  _TMOVECOMMAND._serialized_start=11396
  _TMOVECOMMAND._serialized_end=11540
  _TPDISKSTAT._serialized_start=11542
  _TPDISKSTAT._serialized_end=11663
  _TREASSIGNEDITEM._serialized_start=11666
  _TREASSIGNEDITEM._serialized_end=11884
  _TCONFIGRESPONSE._serialized_start=11887
  _TCONFIGRESPONSE._serialized_end=13531
  _TCONFIGRESPONSE_TSTATUS._serialized_start=12011
  _TCONFIGRESPONSE_TSTATUS._serialized_end=13531
  _TCONFIGRESPONSE_TSTATUS_TFAILPARAM._serialized_start=12887
  _TCONFIGRESPONSE_TSTATUS_TFAILPARAM._serialized_end=13285
  _TCONFIGRESPONSE_TSTATUS_EFAILREASON._serialized_start=13288
  _TCONFIGRESPONSE_TSTATUS_EFAILREASON._serialized_end=13531
# @@protoc_insertion_point(module_scope)



import ydb.core.protos.blobstorage_config_pb2 as kikimr_bsconfig
import ydb.core.protos.blobstorage_disk_color_pb2 as disk_color
import ydb.apps.dstool.lib.table as table
import ydb.apps.dstool.lib.common as common

description = 'Get cluster wide settings'


def add_options(p):
    table.TableOutput([]).add_options(p)


def fetch_settings(args):
    request = common.create_bsc_request(args)
    request.Command.add().ReadSettings.CopyFrom(kikimr_bsconfig.TReadSettings())
    response = common.invoke_bsc_request(request)
    assert len(response.Status) == 1
    assert response.Status[0].Success, 'ReadSettings failed with error: %s' % response.Status[0].ErrorDescription
    return response.Status[0].Settings


def do(args):
    columns = [
        'DefaultMaxSlots',
        'EnableSelfHeal',
        'EnableDonorMode',
        'ScrubPeriodicitySeconds',
        'PDiskSpaceMarginPromille',
        'GroupReserveMin',
        'GroupReservePartPPM',
        'MaxScrubbedDisksAtOnce',
        'EnableGroupLayoutSanitizer',
        'PDiskSpaceColorBorder',
        'SerialManagementStage',
    ]

    table_output = table.TableOutput(columns, default_visible_columns=columns)

    settings = fetch_settings(args)
    row = {}
    for attr in columns:
        if not hasattr(settings, attr):
            continue
        value = getattr(settings, attr)[0]
        if attr == 'PDiskSpaceColorBorder':
            row[attr] = disk_color.TPDiskSpaceColor.E.Name(value)
        elif attr == 'SerialManagementStage':
            row[attr] = kikimr_bsconfig.TSerialManagementStage.E.Name(value)
        else:
            row[attr] = value

    table_output.dump([row], args)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/yq/libs/config/protos/rate_limiter.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.yq.libs.config.protos import storage_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_storage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1ydb/core/yq/libs/config/protos/rate_limiter.proto\x12\x0bNYq.NConfig\x1a,ydb/core/yq/libs/config/protos/storage.proto\"(\n\x08TLimiter\x12\x1c\n\x14\x43oordinationNodePath\x18\x01 \x01(\t\"\xb7\x01\n\x12TRateLimiterConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12\x1b\n\x13\x43ontrolPlaneEnabled\x18\x02 \x01(\x08\x12\x18\n\x10\x44\x61taPlaneEnabled\x18\x03 \x01(\x08\x12\x30\n\x08\x44\x61tabase\x18\x04 \x01(\x0b\x32\x1e.NYq.NConfig.TYdbStorageConfig\x12\'\n\x08Limiters\x18\x05 \x03(\x0b\x32\x15.NYq.NConfig.TLimiterB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.yq.libs.config.protos.rate_limiter_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TLIMITER._serialized_start=112
  _TLIMITER._serialized_end=152
  _TRATELIMITERCONFIG._serialized_start=155
  _TRATELIMITERCONFIG._serialized_end=338
# @@protoc_insertion_point(module_scope)



import sys
import csv
import json
import ydb.apps.dstool.lib.common as common
from itertools import groupby
from collections import defaultdict, OrderedDict

dialect_map = {
    'csv': 'excel',
    'tsv': 'excel-tab',
}


class TableOutput(object):
    def __init__(self, cols_order, default_sort_order=None, human_readable_fn=None, aggregations=None, aggr_drop=None,
                 col_units=None, col_names=None, right_align=None, default_visible_columns=None, default_values=None):
        self.rows = []
        self.cols_order = cols_order
        self.col_names = col_names if col_names is not None else {}
        self.default_sort_order = default_sort_order or self.cols_order
        self.human_readable_fn = human_readable_fn
        self.aggregations = aggregations if aggregations else {}
        self.aggr_drop = aggr_drop if aggr_drop else set()
        self.right_align = right_align if right_align else set()
        self.default_visible_columns = default_visible_columns if default_visible_columns else set()
        self.default_values = default_values if default_values else {}

        if col_units is not None:
            def make_it_human_readable(row):
                for key, value in col_units.items():
                    if key not in row:
                        continue
                    cell = row[key]
                    if value == 'bytes':
                        cell = f'{common.bytes_string(cell)}'
                    elif value == '%':
                        cell = '{0:.1%}'.format(cell)if cell is not None else 'None'
                    else:
                        assert False
                    row[key] = cell
                return human_readable_fn(row) if human_readable_fn else row
            self.human_readable_fn = make_it_human_readable

    def add_options(self, p):
        g = p.add_argument_group('Output format control')
        if self.aggregations:
            g.add_argument('--aggregate', '-a', type=str, nargs='*', choices=list(self.aggregations), help='Aggregate values in table')
        if self.human_readable_fn:
            g.add_argument('--human-readable', '-H', action='store_true', help='Show human-readable output')
        g.add_argument('--sort-by', type=str, default=','.join(self.default_sort_order), help='Sort order')
        g.add_argument('--reverse', action='store_true', help='Reverse sort')
        g.add_argument('--format', type=str, choices=['pretty', 'json', 'tsv', 'csv'], default='pretty', help='Output format control')
        g.add_argument('--no-header', action='store_true', help='Do not output header line')
        g.add_argument('--columns', nargs='*', help='Columns for show')
        g.add_argument('--all-columns', '-A', action='store_true', help='Show all columns')

    def dump(self, rows, args):
        if rows is None:
            return
        if self.aggregations:
            for aggr_name in args.aggregate or []:
                self.aggregate_table(rows, *self.aggregations[aggr_name])

        all_fields = {key for d in rows for key in d}
        if args.sort_by:
            columns_for_sort = [col for col in args.sort_by.split(',') if col in all_fields]

            def key_func(d):
                def getter(key):
                    return d.get(key, self.default_values.get(key))
                return tuple(map(getter, columns_for_sort))

            rows.sort(key=key_func, reverse=args.reverse)

        if self.human_readable_fn and args.human_readable:
            for d in rows:
                self.human_readable_fn(d)

        visible_columns = self.default_visible_columns
        if args.columns:
            visible_columns = set(args.columns)

        cols_order = [cn for cn in self.cols_order if cn in all_fields] + sorted(all_fields - set(self.cols_order))
        if visible_columns and not args.all_columns:
            cols_order = [column for column in cols_order if column in visible_columns]
        rows[:] = [
            OrderedDict((key, r.get(key)) for key in cols_order)
            for r in rows
        ]

        if args.format == 'pretty':
            maxw = defaultdict(int)
            for d in rows:
                for key, value in d.items():
                    maxw[key] = max(maxw[key], len(str(value)), 0 if args.no_header else len(self.col_names.get(key, key)))

            print('┌─', '─┬─'.join('─' * maxw[key] for key in cols_order), '─┐', sep='')
            if not args.no_header:
                print('│', ' │ '.join('%-*s' % (maxw[key], self.col_names.get(key, key)) for key in cols_order), '│')
            for idx, r in enumerate(rows):
                if not idx and not args.no_header:
                    print('├─', '─┼─'.join('─' * maxw[key] for key in cols_order), '─┤', sep='')
                print('│', ' │ '.join('%*s' % (maxw[key] * (1 if key in self.right_align else -1), value if value is not None else '') for key, value in r.items()), '│')
            print('└─', '─┴─'.join('─' * maxw[key] for key in cols_order), '─┘', sep='')
        elif args.format == 'json':
            json.dump(rows, sys.stdout, indent=2)
        elif args.format in ['tsv', 'csv']:
            writer = csv.writer(sys.stdout, dialect_map[args.format], lineterminator='\n')
            if not args.no_header:
                writer.writerow(cols_order)
            for r in rows:
                writer.writerow(r.values())

    def aggregate_table(self, rows, fields_to_aggr, aggr_fn):
        all_fields = {key for d in rows for key in d}
        prefix_fields = sorted(all_fields - set(fields_to_aggr) - set(self.aggr_drop))

        def prefix_getter(d):
            return tuple(map(d.get, prefix_fields))

        rows.sort(key=prefix_getter)

        rows[:] = [
            aggr_fn(dict(zip(prefix_fields, prefix)), row_group)
            for prefix, row_group in groupby(rows, prefix_getter)
        ]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blobstorage_disk.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import blobstorage_disk_color_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__disk__color__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ydb/core/protos/blobstorage_disk.proto\x12\x12NKikimrBlobStorage\x1a,ydb/core/protos/blobstorage_disk_color.proto\"\xcf\x03\n\x0bTPDiskState\"\xbf\x03\n\x01\x45\x12\x0b\n\x07Initial\x10\x00\x12\x15\n\x11InitialFormatRead\x10\x01\x12\x1a\n\x16InitialFormatReadError\x10\x02\x12\x15\n\x11InitialSysLogRead\x10\x03\x12\x1a\n\x16InitialSysLogReadError\x10\x04\x12\x1b\n\x17InitialSysLogParseError\x10\x05\x12\x18\n\x14InitialCommonLogRead\x10\x06\x12\x1d\n\x19InitialCommonLogReadError\x10\x07\x12\x1e\n\x1aInitialCommonLogParseError\x10\x08\x12\x19\n\x15\x43ommonLoggerInitError\x10\t\x12\n\n\x06Normal\x10\n\x12\x11\n\rOpenFileError\x10\x0b\x12\x13\n\x0f\x43hunkQuotaError\x10\x0c\x12\x11\n\rDeviceIoError\x10\r\x12\x0e\n\nReserved14\x10\x0e\x12\x0e\n\nReserved15\x10\x0f\x12\x0e\n\nReserved16\x10\x10\x12\x0c\n\x07Missing\x10\xfc\x01\x12\x0c\n\x07Timeout\x10\xfd\x01\x12\x15\n\x10NodeDisconnected\x10\xfe\x01\x12\x0c\n\x07Unknown\x10\xff\x01\"a\n\x08TVDiskID\x12\x0f\n\x07GroupID\x18\x01 \x01(\r\x12\x17\n\x0fGroupGeneration\x18\x02 \x01(\r\x12\x0c\n\x04Ring\x18\x03 \x01(\r\x12\x0e\n\x06\x44omain\x18\x04 \x01(\r\x12\r\n\x05VDisk\x18\x05 \x01(\r\"<\n\x08TVSlotId\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0f\n\x07PDiskId\x18\x02 \x01(\r\x12\x0f\n\x07VSlotId\x18\x03 \x01(\r\"\x99\x02\n\rTVDiskMetrics\x12-\n\x07VDiskId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10SatisfactionRank\x18\x02 \x01(\r\x12\x15\n\rAvailableSize\x18\x03 \x01(\x04\x12\x15\n\rAllocatedSize\x18\x04 \x01(\x04\x12\x13\n\x0bStatusFlags\x18\x07 \x01(\r\x12-\n\x07VSlotId\x18\x08 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12\x11\n\tOccupancy\x18\t \x01(\x01\x12:\n\nSpaceColor\x18\n \x01(\x0e\x32&.NKikimrBlobStorage.TPDiskSpaceColor.E\"\xab\x02\n\rTPDiskMetrics\x12\x0f\n\x07PDiskId\x18\x01 \x01(\r\x12\x15\n\rAvailableSize\x18\x02 \x01(\x04\x12\x11\n\tTotalSize\x18\x03 \x01(\x04\x12\x19\n\x11MaxReadThroughput\x18\x04 \x01(\x04\x12\x1a\n\x12MaxWriteThroughput\x18\x05 \x01(\x04\x12\x15\n\rNonRealTimeMs\x18\x06 \x01(\x04\x12\x14\n\x0cSlowDeviceMs\x18\x07 \x01(\x04\x12\x0f\n\x07MaxIOPS\x18\x08 \x01(\r\x12\x1f\n\x17\x45nforcedDynamicSlotSize\x18\t \x01(\x04\x12\x30\n\x05State\x18\n \x01(\x0e\x32!.NKikimrBlobStorage.TPDiskState.E\x12\x17\n\x0fUpdateTimestamp\x18\x0b \x01(\x04\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blobstorage_disk_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TPDISKSTATE._serialized_start=109
  _TPDISKSTATE._serialized_end=572
  _TPDISKSTATE_E._serialized_start=125
  _TPDISKSTATE_E._serialized_end=572
  _TVDISKID._serialized_start=574
  _TVDISKID._serialized_end=671
  _TVSLOTID._serialized_start=673
  _TVSLOTID._serialized_end=733
  _TVDISKMETRICS._serialized_start=736
  _TVDISKMETRICS._serialized_end=1017
  _TPDISKMETRICS._serialized_start=1020
  _TPDISKMETRICS._serialized_end=1319
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/yq/libs/config/protos/gateways.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.library.yql.providers.common.proto import gateways_config_pb2 as ydb_dot_library_dot_yql_dot_providers_dot_common_dot_proto_dot_gateways__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ydb/core/yq/libs/config/protos/gateways.proto\x12\x0bNYq.NConfig\x1a<ydb/library/yql/providers/common/proto/gateways_config.proto\"\x91\x02\n\x0fTGatewaysConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12\"\n\x02\x44q\x18\x02 \x01(\x0b\x32\x16.NYql.TDqGatewayConfig\x12\"\n\x02Pq\x18\x03 \x01(\x0b\x32\x16.NYql.TPqGatewayConfig\x12$\n\x03Ydb\x18\x04 \x01(\x0b\x32\x17.NYql.TYdbGatewayConfig\x12\"\n\x02S3\x18\x05 \x01(\x0b\x32\x16.NYql.TS3GatewayConfig\x12,\n\x07Solomon\x18\x06 \x01(\x0b\x32\x1b.NYql.TSolomonGatewayConfig\x12-\n\x0bHttpGateway\x18\x07 \x01(\x0b\x32\x18.NYql.THttpGatewayConfigB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.yq.libs.config.protos.gateways_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TGATEWAYSCONFIG._serialized_start=125
  _TGATEWAYSCONFIG._serialized_end=398
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/datashard_load.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import tx_datashard_pb2 as ydb_dot_core_dot_protos_dot_tx__datashard__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/core/protos/datashard_load.proto\x12\x14NKikimrDataShardLoad\x1a\"ydb/core/protos/tx_datashard.proto\"\xd5\n\n\x16TEvYCSBTestLoadRequest\x12\x0b\n\x03Tag\x18\x01 \x01(\x04\x12\x1a\n\x12NotifyWhenFinished\x18\x02 \x01(\x08\x12L\n\nTableSetup\x18\x03 \x01(\x0b\x32\x38.NKikimrDataShardLoad.TEvYCSBTestLoadRequest.TTableSetup\x12N\n\x0bTargetShard\x18\x04 \x01(\x0b\x32\x39.NKikimrDataShardLoad.TEvYCSBTestLoadRequest.TTargetShard\x12J\n\x08LoadStop\x18\x14 \x01(\x0b\x32\x36.NKikimrDataShardLoad.TEvYCSBTestLoadRequest.TLoadStopH\x00\x12T\n\x0fUpsertBulkStart\x18\x15 \x01(\x0b\x32\x39.NKikimrDataShardLoad.TEvYCSBTestLoadRequest.TUpdateStartH\x00\x12Y\n\x14UpsertLocalMkqlStart\x18\x16 \x01(\x0b\x32\x39.NKikimrDataShardLoad.TEvYCSBTestLoadRequest.TUpdateStartH\x00\x12S\n\x0eUpsertKqpStart\x18\x17 \x01(\x0b\x32\x39.NKikimrDataShardLoad.TEvYCSBTestLoadRequest.TUpdateStartH\x00\x12W\n\x12UpsertProposeStart\x18\x18 \x01(\x0b\x32\x39.NKikimrDataShardLoad.TEvYCSBTestLoadRequest.TUpdateStartH\x00\x12T\n\x11ReadIteratorStart\x18\x19 \x01(\x0b\x32\x37.NKikimrDataShardLoad.TEvYCSBTestLoadRequest.TReadStartH\x00\x1a/\n\tTLoadStop\x12\x0b\n\x03Tag\x18\x01 \x01(\x04\x12\x15\n\rRemoveAllTags\x18\x02 \x01(\x08\x1aX\n\x0cTTargetShard\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x0f\n\x07TableId\x18\x02 \x01(\x04\x12\x12\n\nWorkingDir\x18\x03 \x01(\t\x12\x11\n\tTableName\x18\x04 \x01(\t\x1ak\n\x0cTUpdateStart\x12\x10\n\x08RowCount\x18\x01 \x01(\x04\x12\x10\n\x08Inflight\x18\x02 \x01(\r\x12\x12\n\x07KeyFrom\x18\x03 \x01(\x04:\x01\x30\x12\x10\n\x08Infinite\x18\x04 \x01(\x08\x12\x11\n\tBatchSize\x18\x05 \x01(\r\x1a\xb5\x01\n\nTReadStart\x12\x10\n\x08RowCount\x18\x01 \x01(\x04\x12\x11\n\tReadCount\x18\x02 \x01(\x04\x12\x11\n\tInflights\x18\x03 \x03(\r\x12\x0e\n\x06\x43hunks\x18\x04 \x03(\r\x12\x39\n\x0cResultFormat\x18\x05 \x01(\x0e\x32#.NKikimrTxDataShard.EScanDataFormat\x12\x10\n\x08Infinite\x18\x06 \x01(\x08\x12\x12\n\nNoFullScan\x18\x07 \x01(\x08\x1a\xb7\x01\n\x0bTTableSetup\x12\x12\n\nWorkingDir\x18\x01 \x01(\t\x12\x11\n\tTableName\x18\x02 \x01(\t\x12\x11\n\tDropTable\x18\x03 \x01(\x08\x12\x13\n\x0b\x43reateTable\x18\x04 \x01(\x08\x12\x13\n\x08MinParts\x18\x05 \x01(\x04:\x01\x31\x12\x13\n\x08MaxParts\x18\x06 \x01(\x04:\x01\x31\x12\x1b\n\rMaxPartSizeMb\x18\x07 \x01(\x04:\x04\x32\x30\x30\x30\x12\x12\n\nSkipWarmup\x18\x08 \x01(\x08\x42\t\n\x07\x43ommand\"W\n\x13TEvTestLoadResponse\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x13\n\x0b\x45rrorReason\x18\x02 \x01(\t\x12\x0e\n\x06\x43ookie\x18\x03 \x01(\x04\x12\x0b\n\x03Tag\x18\x04 \x01(\x04\"\x95\x01\n\x0bTLoadReport\x12\x0b\n\x03Tag\x18\x01 \x01(\x04\x12\x12\n\nDurationMs\x18\x02 \x01(\x04\x12\x14\n\x0cOperationsOK\x18\x03 \x01(\x04\x12\x17\n\x0fOperationsError\x18\x04 \x01(\x04\x12\x0c\n\x04Info\x18\x05 \x01(\t\x12\x14\n\x0cSubtestCount\x18\x06 \x01(\x04\x12\x12\n\nPrefixInfo\x18\x07 \x01(\t\"\x18\n\x16TEvTestLoadInfoRequest\"M\n\x17TEvTestLoadInfoResponse\x12\x32\n\x07Reports\x18\x01 \x03(\x0b\x32!.NKikimrDataShardLoad.TLoadReport\"j\n\x13TEvTestLoadFinished\x12\x0b\n\x03Tag\x18\x01 \x01(\x04\x12\x31\n\x06Report\x18\x02 \x01(\x0b\x32!.NKikimrDataShardLoad.TLoadReport\x12\x13\n\x0b\x45rrorReason\x18\x03 \x01(\tB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.datashard_load_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TEVYCSBTESTLOADREQUEST._serialized_start=99
  _TEVYCSBTESTLOADREQUEST._serialized_end=1464
  _TEVYCSBTESTLOADREQUEST_TLOADSTOP._serialized_start=837
  _TEVYCSBTESTLOADREQUEST_TLOADSTOP._serialized_end=884
  _TEVYCSBTESTLOADREQUEST_TTARGETSHARD._serialized_start=886
  _TEVYCSBTESTLOADREQUEST_TTARGETSHARD._serialized_end=974
  _TEVYCSBTESTLOADREQUEST_TUPDATESTART._serialized_start=976
  _TEVYCSBTESTLOADREQUEST_TUPDATESTART._serialized_end=1083
  _TEVYCSBTESTLOADREQUEST_TREADSTART._serialized_start=1086
  _TEVYCSBTESTLOADREQUEST_TREADSTART._serialized_end=1267
  _TEVYCSBTESTLOADREQUEST_TTABLESETUP._serialized_start=1270
  _TEVYCSBTESTLOADREQUEST_TTABLESETUP._serialized_end=1453
  _TEVTESTLOADRESPONSE._serialized_start=1466
  _TEVTESTLOADRESPONSE._serialized_end=1553
  _TLOADREPORT._serialized_start=1556
  _TLOADREPORT._serialized_end=1705
  _TEVTESTLOADINFOREQUEST._serialized_start=1707
  _TEVTESTLOADINFOREQUEST._serialized_end=1731
  _TEVTESTLOADINFORESPONSE._serialized_start=1733
  _TEVTESTLOADINFORESPONSE._serialized_end=1810
  _TEVTESTLOADFINISHED._serialized_start=1812
  _TEVTESTLOADFINISHED._serialized_end=1918
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/node_broker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import interconnect_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_interconnect__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/node_broker.proto\x12\x11NKikimrNodeBroker\x1a,library/cpp/actors/protos/interconnect.proto\"C\n\nTListNodes\x12\x12\n\x08MinEpoch\x18\x01 \x01(\x04H\x00\x12\x17\n\rCachedVersion\x18\x02 \x01(\x04H\x00\x42\x08\n\x06\x46ilter\"\xa3\x01\n\tTNodeInfo\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0c\n\x04Host\x18\x02 \x01(\t\x12\x0c\n\x04Port\x18\x03 \x01(\r\x12\x13\n\x0bResolveHost\x18\x04 \x01(\t\x12\x0f\n\x07\x41\x64\x64ress\x18\x05 \x01(\t\x12\x34\n\x08Location\x18\x06 \x01(\x0b\x32\".NActorsInterconnect.TNodeLocation\x12\x0e\n\x06\x45xpire\x18\x07 \x01(\x04\"R\n\x06TEpoch\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\x0f\n\x07Version\x18\x02 \x01(\x04\x12\r\n\x05Start\x18\x03 \x01(\x04\x12\x0b\n\x03\x45nd\x18\x04 \x01(\x04\x12\x0f\n\x07NextEnd\x18\x05 \x01(\x04\"\xa7\x01\n\nTNodesInfo\x12\x0e\n\x06\x44omain\x18\x01 \x01(\r\x12+\n\x05Nodes\x18\x02 \x03(\x0b\x32\x1c.NKikimrNodeBroker.TNodeInfo\x12\x32\n\x0c\x45xpiredNodes\x18\x03 \x03(\x0b\x32\x1c.NKikimrNodeBroker.TNodeInfo\x12(\n\x05\x45poch\x18\x04 \x01(\x0b\x32\x19.NKikimrNodeBroker.TEpoch\"\x1e\n\x0cTResolveNode\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\"\xa7\x01\n\x07TStatus\x12.\n\x04\x43ode\x18\x01 \x01(\x0e\x32 .NKikimrNodeBroker.TStatus.ECode\x12\x0e\n\x06Reason\x18\x02 \x01(\t\"\\\n\x05\x45\x43ode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0e\n\nERROR_TEMP\x10\x03\x12\x11\n\rWRONG_REQUEST\x10\x04\x12\x10\n\x0cUNAUTHORIZED\x10\x05\"g\n\rTResolvedNode\x12*\n\x06Status\x18\x01 \x01(\x0b\x32\x1a.NKikimrNodeBroker.TStatus\x12*\n\x04Node\x18\x02 \x01(\x0b\x32\x1c.NKikimrNodeBroker.TNodeInfo\"\xd2\x01\n\x14TRegistrationRequest\x12\x0c\n\x04Host\x18\x01 \x01(\t\x12\x0c\n\x04Port\x18\x02 \x01(\r\x12\x13\n\x0bResolveHost\x18\x03 \x01(\t\x12\x0f\n\x07\x41\x64\x64ress\x18\x04 \x01(\t\x12\x34\n\x08Location\x18\x05 \x01(\x0b\x32\".NActorsInterconnect.TNodeLocation\x12\x13\n\x0b\x46ixedNodeId\x18\x06 \x01(\x08\x12\x0c\n\x04Path\x18\x07 \x01(\t\x12\x1f\n\x17\x41uthorizedByCertificate\x18\x08 \x01(\x08\"\x9b\x01\n\x15TRegistrationResponse\x12*\n\x06Status\x18\x01 \x01(\x0b\x32\x1a.NKikimrNodeBroker.TStatus\x12*\n\x04Node\x18\x02 \x01(\x0b\x32\x1c.NKikimrNodeBroker.TNodeInfo\x12\x15\n\rScopeTabletId\x18\x03 \x01(\x04\x12\x13\n\x0bScopePathId\x18\x04 \x01(\x04\"%\n\x13TExtendLeaseRequest\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\"\x8c\x01\n\x14TExtendLeaseResponse\x12*\n\x06Status\x18\x01 \x01(\x0b\x32\x1a.NKikimrNodeBroker.TStatus\x12\x0e\n\x06NodeId\x18\x02 \x01(\r\x12\x0e\n\x06\x45xpire\x18\x03 \x01(\x04\x12(\n\x05\x45poch\x18\x04 \x01(\x0b\x32\x19.NKikimrNodeBroker.TEpoch\"\x8e\x01\n\x07TConfig\x12!\n\rEpochDuration\x18\x01 \x01(\x04:\n3600000000\x12:\n\rBannedNodeIds\x18\x02 \x03(\x0b\x32#.NKikimrNodeBroker.TConfig.TNodeIds\x1a$\n\x08TNodeIds\x12\x0c\n\x04\x46rom\x18\x01 \x01(\r\x12\n\n\x02To\x18\x02 \x01(\r\"\x13\n\x11TGetConfigRequest\"@\n\x12TGetConfigResponse\x12*\n\x06\x43onfig\x18\x01 \x01(\x0b\x32\x1a.NKikimrNodeBroker.TConfig\"?\n\x11TSetConfigRequest\x12*\n\x06\x43onfig\x18\x01 \x01(\x0b\x32\x1a.NKikimrNodeBroker.TConfig\"@\n\x12TSetConfigResponse\x12*\n\x06Status\x18\x01 \x01(\x0b\x32\x1a.NKikimrNodeBroker.TStatusB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.node_broker_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TLISTNODES._serialized_start=102
  _TLISTNODES._serialized_end=169
  _TNODEINFO._serialized_start=172
  _TNODEINFO._serialized_end=335
  _TEPOCH._serialized_start=337
  _TEPOCH._serialized_end=419
  _TNODESINFO._serialized_start=422
  _TNODESINFO._serialized_end=589
  _TRESOLVENODE._serialized_start=591
  _TRESOLVENODE._serialized_end=621
  _TSTATUS._serialized_start=624
  _TSTATUS._serialized_end=791
  _TSTATUS_ECODE._serialized_start=699
  _TSTATUS_ECODE._serialized_end=791
  _TRESOLVEDNODE._serialized_start=793
  _TRESOLVEDNODE._serialized_end=896
  _TREGISTRATIONREQUEST._serialized_start=899
  _TREGISTRATIONREQUEST._serialized_end=1109
  _TREGISTRATIONRESPONSE._serialized_start=1112
  _TREGISTRATIONRESPONSE._serialized_end=1267
  _TEXTENDLEASEREQUEST._serialized_start=1269
  _TEXTENDLEASEREQUEST._serialized_end=1306
  _TEXTENDLEASERESPONSE._serialized_start=1309
  _TEXTENDLEASERESPONSE._serialized_end=1449
  _TCONFIG._serialized_start=1452
  _TCONFIG._serialized_end=1594
  _TCONFIG_TNODEIDS._serialized_start=1558
  _TCONFIG_TNODEIDS._serialized_end=1594
  _TGETCONFIGREQUEST._serialized_start=1596
  _TGETCONFIGREQUEST._serialized_end=1615
  _TGETCONFIGRESPONSE._serialized_start=1617
  _TGETCONFIGRESPONSE._serialized_end=1681
  _TSETCONFIGREQUEST._serialized_start=1683
  _TSETCONFIGREQUEST._serialized_end=1746
  _TSETCONFIGRESPONSE._serialized_start=1748
  _TSETCONFIGRESPONSE._serialized_end=1812
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/pdiskfit.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eydb/core/protos/pdiskfit.proto\x12\tNPDiskFIT\"\x9c\x05\n\x0fTFakeVDiskState\x12\x35\n\x08LogItems\x18\x01 \x03(\x0b\x32#.NPDiskFIT.TFakeVDiskState.TLogItem\x12:\n\rInFlightItems\x18\x02 \x03(\x0b\x32#.NPDiskFIT.TFakeVDiskState.TLogItem\x12\x16\n\x0e\x46irstLsnToKeep\x18\x03 \x01(\x04\x12\x15\n\rBlocksInChunk\x18\x04 \x01(\r\x12\x31\n\x06\x43hunks\x18\x05 \x03(\x0b\x32!.NPDiskFIT.TFakeVDiskState.TChunk\x12?\n\x0eWritesInFlight\x18\x06 \x03(\x0b\x32\'.NPDiskFIT.TFakeVDiskState.TWriteRecord\x1ay\n\x08TLogItem\x12\x0b\n\x03Lsn\x18\x01 \x01(\x04\x12\x11\n\tSignature\x18\x02 \x01(\r\x12\x0f\n\x07\x44\x61taLen\x18\x03 \x01(\r\x12\x10\n\x08\x43hecksum\x18\x04 \x01(\r\x12\x14\n\x0c\x43ommitChunks\x18\x05 \x03(\r\x12\x14\n\x0c\x44\x65leteChunks\x18\x06 \x03(\r\x1a\x94\x01\n\x06TChunk\x12\x10\n\x08\x43hunkIdx\x18\x01 \x01(\r\x12\x38\n\x06\x42locks\x18\x02 \x03(\x0b\x32(.NPDiskFIT.TFakeVDiskState.TChunk.TBlock\x12\x13\n\x0b\x43ommitState\x18\x03 \x01(\r\x1a)\n\x06TBlock\x12\r\n\x05Index\x18\x01 \x01(\r\x12\x10\n\x08\x43hecksum\x18\x02 \x01(\r\x1a\x61\n\x0cTWriteRecord\x12\x10\n\x08\x43hunkIdx\x18\x01 \x01(\r\x12\x16\n\x0eOffsetInBlocks\x18\x02 \x01(\r\x12\x14\n\x0cSizeInBlocks\x18\x03 \x01(\r\x12\x11\n\tChecksums\x18\x04 \x03(\r\"q\n\x14TObjectWithStateDict\x12\x34\n\x05Items\x18\x01 \x03(\x0b\x32%.NPDiskFIT.TObjectWithStateDict.TItem\x1a#\n\x05TItem\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\x0c')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.pdiskfit_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TFAKEVDISKSTATE._serialized_start=46
  _TFAKEVDISKSTATE._serialized_end=714
  _TFAKEVDISKSTATE_TLOGITEM._serialized_start=343
  _TFAKEVDISKSTATE_TLOGITEM._serialized_end=464
  _TFAKEVDISKSTATE_TCHUNK._serialized_start=467
  _TFAKEVDISKSTATE_TCHUNK._serialized_end=615
  _TFAKEVDISKSTATE_TCHUNK_TBLOCK._serialized_start=574
  _TFAKEVDISKSTATE_TCHUNK_TBLOCK._serialized_end=615
  _TFAKEVDISKSTATE_TWRITERECORD._serialized_start=617
  _TFAKEVDISKSTATE_TWRITERECORD._serialized_end=714
  _TOBJECTWITHSTATEDICT._serialized_start=716
  _TOBJECTWITHSTATEDICT._serialized_end=829
  _TOBJECTWITHSTATEDICT_TITEM._serialized_start=794
  _TOBJECTWITHSTATEDICT_TITEM._serialized_end=829
# @@protoc_insertion_point(module_scope)
